@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@ class OeImportData : public LibImportWizard::AbstractImporter
 {
 public:
     explicit OeImportData(QObject *parent, const QList<QVariant> & = QList<QVariant>());
-    ~OeImportData();
+    ~OeImportData() override;
 
     TypeSupportedOptions supportedOption() override;
     bool foundMailer() const override;
