@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -38,7 +38,7 @@ class TodoEdit : public QWidget
     Q_OBJECT
 public:
     explicit TodoEdit(QWidget *parent = nullptr);
-    ~TodoEdit();
+    ~TodoEdit() override;
 
     Akonadi::Collection collection() const;
     void setCollection(const Akonadi::Collection &value);
